import os
import csv
import json
from airtable import Airtable
from .product import Product


tb = None


def get_json(filename):
    with open(os.path.join(os.path.dirname(__file__), 'data', filename)) as f:
        return json.load(f)


def update_product_topviews(topviews):
    tb = Airtable(table_name="Collectie", base_id="appVz0Sb0OZ0Cwng7",
                  api_key=os.getenv('AIRTABLE_API_KEY'))

    pds = tb.get_all()
    for p in pds:
        if p["fields"]["code"] in topviews:
            print("update topview")
            tb.update(p["id"], {"Topview found": True})


def get_products_by_collection(collection):
    tb = Airtable(table_name="Collectie", base_id="appVz0Sb0OZ0Cwng7",
                  api_key=os.getenv('AIRTABLE_API_KEY'))
    result = tb.search('collection', collection.lower())
    ret = {}
    for r in result:
        ret[r['fields']['code']] = Product(r)
    return ret


def get_products():
    tb = Airtable(table_name="Collectie", base_id="appVz0Sb0OZ0Cwng7",
                  api_key=os.getenv('AIRTABLE_API_KEY'))
    table_list = tb.get_all()
    return json_to_products(table_list)


def json_to_products(json):
    pdList = []
    for j in json:
        pdList.append(Product(j))
    return pdList


def get_tool_database():
    basepath = os.path.dirname(__file__)
    dct = {}
    with open(os.path.join(basepath, 'data', 'database.csv')) as f:
        aList = csv.reader(f, delimiter=';')
        for row in aList:
            if row[0] == 'Material':
                dct[row[5].split('|')[0]] = {
                    'name': row[5].split('|')[1], 'type': row[4]}
                # lst.append(temp)
    return dct




class Product():
    def __init__(self, record):
        self.code = record['fields']['code']
        self.name = record['fields']['name']
        self.type = record['fields']['type']
        self.themes = record['fields']['themes']
        self.collection = record['fields']['collection']
        self.topview_present = True if 'Topview found' in record['fields'].keys(
        ) else False
        self.shader_present = True if 'Shader found' in record['fields'].keys(
        ) else False
        self.data_present = True if 'Database found' in record['fields'].keys(
        ) else False

    def __str__(self) -> str:
        return f"{self.code} - {self.name} ({self.type})"

    def to_dict(self) -> dict:
        return {
            'name': self.name,
            'code': self.code,
            'collection': self.collection,
            'themes': self.themes,
            'topview': self.topview_present,
            'shader': self.shader_present,
            'database': self.data_present
        }



from airtable import Airtable
import zipfile
from pathlib import Path
import os
from math import prod
topviewlist = []


base = "appVz0Sb0OZ0Cwng7"
path = "/Volumes/DOWNLOAD/1082"


def get_products(product_set):
    counter = 0
    tb = Airtable(table_name="Collectie", base_id=base,
                  api_key=os.getenv("AIRTABLE_API_KEY"))
    table_list = tb.get_all()
    for t in table_list:
        # print(t)
        n = t["fields"]["code"]
        if n in product_set:
            print(f"hey i recognize {n}")
            counter += 1

    print(
        f'script found {counter} topviews on F drive out of total {len(table_list)}')


def get_topviews():
    product_set = set()
    for t in Path(path).rglob("*.tif"):
        product_set.add(t.stem.upper())

    for x in Path(path).rglob("*.zip"):
        # print(x)
        if "Topview" in x.name:
            zip = zipfile.ZipFile(x.resolve())
            for file in zip.namelist():
                if "jpg" in file and '(g)' not in file:
                    product = file.split('/')[-1].split('.')[0]

                    if product not in product_set:
                        product_set.add(product)

    return product_set

# tifs = glob.glob('**/*.txt', recursive=True)

# with os.scandir(dir) as it:
#     for entry in it:
#         if entry.name.endswith(".tif") and entry.is_file():
#             print(entry.name, entry.path)
#         if entry.name.endswith(".zip") and entry.is_file():
#             print(entry.name, entry.path)
#         if entry.is_dir:
#             print(entry.path)


# for p in os.listdir(dir):
#     sub = os.path.join(dir, p)
#     if os.path.isdir(sub):
#         print(f"{p} is dir so...")
#         for s in os.listdir(sub):
#             print(s)
#             if os.path.isdir(os.path.join(sub,s)):
#                 probe = os.path.join(sub, s)
#                 if os.path.isdir(probe):
#                     for file in os.listdir(probe):
#                         if "tif" in file:
#                             topviewlist.append(file.upper().split('.')[0])
#     if os.path.isfile:
#         print(f"{p} is a file, but is it zip?")


# with open('data/topviews.json', 'w') as f:
#     json.dump(topviewlist, f)


# tb = Airtable('appVz0Sb0OZ0Cwng7', 'Collectie', api_key=os.environ["AIRTABLE_API_KEY"])

# for x in tb.get_all():
#     if x["fields"]["code"] in topviewlist:
#         tb.update(x['id'], fields={'Topview found':'true'}, typecast=True)



import os
import click
from pick import pick

from . import __version__
from .translate import translate_file
from .data import get_products, get_json, get_tool_database, get_products_by_collection, update_product_topviews
from .topviews import get_topviews


@click.command()
@click.option("--update", "-u", is_flag=True, help='Updates the Airtable cache on disk')
@click.option("--topviews", "-t", is_flag=True, help='Updates the topviews')
@click.option("--new", "-n", is_flag=True, help='Adding a new collection to the online tool. Type the name of the collection after this flag.')
@click.argument('collection', required=False)
@click.option("--translate", "-t", is_flag=True, help='Use this flag to translate Dutch .txt orders to English.\n Type the name of the file after this flag, e.g. text_to_translate.txt')
@click.version_option(version=__version__)
def main(update, translate, new, collection, topviews):

    if topviews:
        tvs = get_topviews()
        update_product_topviews(tvs)
    if translate:
        files = [f for f in os.listdir(os.getcwd()) if f.endswith('.txt')]
        if len(files) == 0:
            click.secho(
                f"No .txt files found in {os.getcwd()}", fg='yellow')
        elif len(files) == 1:
            translate_file(files[0])
        else:
            option = pick(
                files, "Choose the file to translate:", indicator='=>')
            translate_file(option[0])

    if collection is not None and new is False and translate is False:
        click.secho(
            f'Did you mean to run the script with the --new flag for {collection}? Try again using: masureel --new {collection}', fg='yellow')
    if new:
        if collection is None:
            click.secho(
                'Specify a collection by typing the name after the --new flag, like this: masureel --new collection', fg='red')
        else:
            collection = collection.capitalize()
            collections = get_json('collections.json')
            if collection in collections:
                print(f'We found an entry for {collection}, grabbing records')
                batch = get_products_by_collection(collection)
                for code, product in batch.items():
                    print(code, product)
                    if product.data_present:
                        print(
                            f'{product} is already present in the online tool as a {product.type}')
                    if product.shader_present:
                        print(f'we already have the shader for {product}')
                    if product.topview_present:
                        print(f"we already have a topview for {product}")
            else:
                click.secho(
                    f"Hmmm, can't find {collection} in our database...", fg='red')
    if update:
        # getting airtable pds
        pds = get_products()
        # grabbing pds from database.csv
        online_products = get_tool_database()
        # grabbing shaders from .matlib
        shaders = get_json('shaders.json')
        for p in pds:
            if p.code in online_products.keys():
                print(
                    f'{p.name} is present in the online tool, values are {online_products[p.code]}')
            if p.code in shaders.keys():
                print(f'{p.name} is present in matlib, we can create render jobs!')



from inspect import indentsize
from openpyxl import load_workbook
import json
import os


def parse_cabinet(excel_file):
    collection = excel_file
    file = os.path.join(os.path.dirname(__file__),
                        'data', f"{excel_file}.xlsx")
    ws = load_workbook(file).active
    minrow = int(ws.min_row)
    maxrow = int(ws.max_row)
    lst = []
    retdict = {}
    for row in ws.iter_rows(minrow, maxrow):
        for cell in row:
            if cell.value is not None:
                if "KLEURTHEMA" in cell.value:
                    lst.append(int(cell.row))

    for index in range(len(lst)):
        max = 0
        min = lst[index]
        max = lst[index + 1] if index != len(lst) - 1 else maxrow
        for index, row in enumerate(ws.iter_rows(min, max)):
            # print("-------------------------------------------------------")
            for cell in row:
                if cell.value is not None:
                    if "KLEURTHEMA" in cell.value:
                        color_theme = val_to_color_theme(cell.value)
                    elif "BEHANG" in cell.value:
                        product_type = "wallpaper"
                    elif "VERF" in cell.value:
                        product_type = "paint"
                    elif "STOF" in cell.value:
                        product_type = "fabric"
                    else:
                        name = ws.cell(row=min + index, column=7).value
                        code = ws.cell(row=min + index, column=6).value
                        #print(cell, cell.value)
            if name is not None and code is not None:
                retdict[code] = {
                    'name': val_to_name(name),
                    'code': code,
                    'color_theme': color_theme,
                    'product_type': product_type,
                    'collection': collection
                }
    return retdict


def parse_excel(excel_file):
    collection = excel_file
    # print(collection)
    file = os.path.join(os.path.dirname(__file__),
                        'data', f"{excel_file}.xlsx")
    # print(file)
    ws = load_workbook(file).active
    minrow = int(ws.min_row)
    maxrow = int(ws.max_row)
    lst = []
    for row in ws.iter_rows(minrow, maxrow):
        for cell in row:
            if cell.value is not None:
                # print(cell.value)
                if "KLEURTHEMA" in cell.value:
                    lst.append(int(cell.row))

    color_theme = None
    product_type = None
    retdict = {}

    for index in range(len(lst)):
        max = 0
        min = lst[index]
        max = lst[index + 1] if index != len(lst) - 1 else maxrow
        for index, row in enumerate(ws.iter_rows(min, max)):
            name = None
            code = None
            for cell in row:
                if cell.value is not None:
                    if "KLEURTHEMA" in cell.value:
                        color_theme = val_to_color_theme(cell.value)
                    elif "BEHANG" in cell.value:
                        product_type = "wallpaper"
                    elif "VERF" in cell.value:
                        product_type = "paint"
                    elif "STOF" in cell.value:
                        product_type = "fabric"
                    else:
                        name = ws.cell(row=min + index, column=3).value
                        code = ws.cell(row=min + index, column=7).value
            # print(name)
            # print(code)
            if name is not None and code is not None:
                #print(code, name, color_theme, product_type)
                retdict[code] = {
                    'name': val_to_name(name),
                    'code': code,
                    'color_theme': color_theme,
                    'product_type': product_type,
                    'collection': collection
                }
    return retdict


def val_to_color_theme(value):
    return value[13:].strip().lower().replace(' ', '-')


def val_to_name(value):
    return value.strip().lower().replace(' ', '-')


if __name__ == '__main__':

    bigdict = {}
    bigdict.update(parse_excel('kimono'))
    bigdict.update(parse_excel('orbital'))
    bigdict.update(parse_excel('agathe'))
    bigdict.update(parse_cabinet('cabinet'))
    for product in bigdict.values():
        print(json.dumps(product, indent=2))



import csv
import os
import codecs


def translate_file(filename):
    basepath = os.path.dirname(__file__)
    Dict = []
    with open(os.path.join(basepath, 'data', 'Dict.csv')) as f:
        aList = csv.reader(f, delimiter='|')
        for row in aList:
            Dict.append(row)

    with codecs.open(filename, 'r', encoding='utf-8', errors='ignore') as fdata:
        filedata = fdata.read()

    for i in range(len(Dict)):
        filedata = filedata.replace(Dict[i][0], Dict[i][1])

    with open(f'translated_{filename}', 'w', encoding='utf-8') as file:
        file.write(filedata)



import pymxs, json

# open up a matlib and parse the material names into a list

matpath = "X:/1082_MSR_BHP/Materials/Matlib_full.mat"


rt = pymxs.runtime
rt.loadMaterialLibrary(matpath)
matlib = rt.currentMaterialLibrary

shaders = {}

print(dir(matlib[0]))

print(type(matlib[0]))

for m in matlib:
    try:
        print(m.name, m.texmap_diffuse)
        if m.texmap_diffuse is not None:
            shaders[m.name] = True
        else:
            shaders[m.name] = False
    except:
        
        print(m.name, m.baseMtl)
        if m.baseMtl is not None:
            shaders[m.name] = True
        else:
            shaders[m.name] = False

print(json.dumps(shaders))

with open('shaders_full.json', 'w') as fp:
    json.dump(shaders, fp, indent=2)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['masureel', 'masureel.max']

package_data = \
{'': ['*'], 'masureel': ['data/*']}

install_requires = \
['airtable-python-wrapper>=0.15.3,<0.16.0',
 'click>=8.0.3,<9.0.0',
 'pick>=1.2.0,<2.0.0']

entry_points = \
{'console_scripts': ['masureel = masureel.console:main']}

setup_kwargs = {
    'name': 'masureel',
    'version': '0.1.9.8',
    'description': '',
    'long_description': None,
    'author': 'Lucas Selfslagh',
    'author_email': 'lucas.selfslagh@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<=3.10',
}


setup(**setup_kwargs)
